@@ -82,7 +82,7 @@ def Run_KMeans_Clustering_for_Grids(GRIDS=None, CLUSTER=None, STATISTICS=None, M
     - STATISTICS [`output table`] : Statistics
     - METHOD [`choice`] : Method. Available Choices: [0] Iterative Minimum Distance (Forgy 1965) [1] Hill-Climbing (Rubin 1967) [2] Combined Minimum Distance / Hillclimbing Default: 1
     - NCLUSTER [`integer number`] : Clusters. Minimum: 2 Default: 10 Number of clusters
-    - MAXITER [`integer number`] : Maximum Iterations. Minimum: 0 Default: 10 maximum number of iterations, ignored if set to zero (default)
+    - MAXITER [`integer number`] : Maximum Iterations. Minimum: 0 Default: 10 Maximum number of iterations, ignored if set to zero.
     - NORMALISE [`boolean`] : Normalise. Default: 0 Automatically normalise grids by standard deviation before clustering.
     - INITIALIZE [`choice`] : Start Partition. Available Choices: [0] random [1] periodical [2] keep values Default: 0
     - OLDVERSION [`boolean`] : Old Version. Default: 0 slower but memory saving
