@@ -21,7 +21,7 @@ def Run_Fast_Representativeness(INPUT=None, RESULT=None, RESULT_LOD=None, SEEDS=
     [statistics_grid.0]\n
     A fast representativeness algorithm. Resulting seeds might be used with 'Fast Region Growing'.\n
     References:\n
-    Boehner, J., Selige, T., Ringeler, A. (2006): Image segmentation using representativeness analysis and region growing. In: Boehner, J., McCloy, K.R., Strobl, J. [Eds.]:  SAGA â€“ Analysis and Modelling Applications. Goettinger Geographische Abhandlungen, Vol.115, <a href="http://downloads.sourceforge.net/saga-gis/gga115_03.pdf">pdf</a>\n
+    Boehner, J., Selige, T., Ringeler, A. (2006): Image segmentation using representativeness analysis and region growing. In: Boehner, J., McCloy, K.R., Strobl, J. [Eds.]:  SAGA â€“ Analysis and Modelling Applications. Goettinger Geographische Abhandlungen, Vol.115, [pdf](http://downloads.sourceforge.net/saga-gis/gga115_03.pdf)\n
     Arguments
     ----------
     - INPUT [`input grid`] : Input. Input for tool calculations.
@@ -230,7 +230,11 @@ def Run_Zonal_Grid_Statistics(ZONES=None, CATLIST=None, STATLIST=None, ASPECT=No
     (3) a zonal grid and additional grids with continuous data are used as input. This results in a contingency table with the number of cells in each zone and the corresponding statistics for each continuous grid.\n
     (4) a zonal grid, additional categorical grids and additional grids with continuous data are used as input. This results in a contingency table with the number of cells in each UCU and the corresponding statistics for each continuous grid.\n
     Depending on the mode of operation, the output table contains information about the categorical combination of each UCU, the number of cells in each UCU and the statistics for each UCU. A typical output table may look like this:\n
-    <table border="1"><tr><td>ID UCU</td><td>ID Zone</td><td>ID 1stCat</td><td>ID 2ndCat</td><td>Count UCU</td><td>N 1stCont</td><td>MIN 1stCont</td><td>MAX 1stCont</td><td>MEAN 1stCont</td><td>STDDEV 1stCont</td><td>SUM 1stCont</td></tr><tr><td>1      </td><td>0      </td><td>2        </td><td>6        </td><td>6        </td><td>6        </td><td>708.5      </td><td>862.0      </td><td>734.5       </td><td>62.5          </td><td>4406.8     </td></tr><tr><td>2      </td><td>0      </td><td>3        </td><td>4        </td><td>106      </td><td>106      </td><td>829.1      </td><td>910.1      </td><td>848.8       </td><td>28.5          </td><td>89969.0    </td></tr></table>\n
+    ============\n
+    ID UCU	ID Zone	ID 1stCat	ID 2ndCat	Count UCU	N 1stCont	MIN 1stCont	MAX 1stCont	MEAN 1stCont	STDDEV 1stCont	SUM 1stCont\n
+    1      	0      	2        	6        	6        	6        	708.5      	862.0      	734.5       	62.5          	4406.8\n
+    2      	0      	3        	4        	106      	106      	829.1      	910.1      	848.8       	28.5          	89969.0\n
+    ============\n
     Note: in the case you like to convert some one of the statistics back to a grid dataset, you can use the following procedure. Run the tool and output the UCU grid. Then edit the output table to match your needs (delete all fields besides the UCU identifier and the fields you like to create grids from). Then use both datasets in the "Grids from Classified Grid and Table" tool.\n
     Arguments
     ----------
@@ -284,9 +288,9 @@ def Run_Directional_Statistics_for_Single_Grid(GRID=None, POINTS=None, MEAN=None
     - DIRECTION [`floating point number`] : Direction [Degree]. Default: 0.000000
     - TOLERANCE [`floating point number`] : Tolerance [Degree]. Minimum: 0.000000 Maximum: 45.000000 Default: 0.000000
     - MAXDISTANCE [`integer number`] : Maximum Distance [Cells]. Minimum: 0 Default: 0 Maximum distance parameter is ignored if set to zero (default).
-    - DW_WEIGHTING [`choice`] : Weighting Function. Available Choices: [0] no distance weighting [1] inverse distance to a power [2] exponential [3] gaussian Default: 0
+    - DW_WEIGHTING [`choice`] : Weighting Function. Available Choices: [0] no distance weighting [1] inverse distance to a power [2] exponential [3] gaussian Default: 3
     - DW_IDW_POWER [`floating point number`] : Power. Minimum: 0.000000 Default: 2.000000
-    - DW_BANDWIDTH [`floating point number`] : Bandwidth. Minimum: 0.000000 Default: 1.000000 Bandwidth specified as number of cells.
+    - DW_BANDWIDTH [`floating point number`] : Bandwidth. Minimum: 0.000000 Default: 25.000000 Bandwidth specified as number of cells.
 
     - Verbose [`integer number`] : Verbosity level, 0=silent, 1=tool name and success notification, 2=complete tool output.\n
     Returns
