@@ -318,6 +318,13 @@ CSG_Points::CSG_Points(void)
 	m_Points.Create(sizeof(TSG_Point), 0, TSG_Array_Growth::SG_ARRAY_GROWTH_1);
 }
 
+CSG_Points::CSG_Points(const CSG_Points &Points)
+{
+	m_Points.Create(sizeof(TSG_Point), 0, TSG_Array_Growth::SG_ARRAY_GROWTH_1);
+
+	Assign(Points);
+}
+
 CSG_Points::CSG_Points(sLong nPoints, TSG_Array_Growth Growth)
 {
 	m_Points.Create(sizeof(TSG_Point), nPoints, Growth);
@@ -356,6 +363,181 @@ bool CSG_Points::Add(double x, double y)
 }
 
 
+///////////////////////////////////////////////////////////
+//														 //
+//														 //
+//														 //
+///////////////////////////////////////////////////////////
+
+//---------------------------------------------------------
+CSG_Lines::CSG_Lines(void)
+{
+	m_Lines.Create(0, TSG_Array_Growth::SG_ARRAY_GROWTH_0);
+}
+
+CSG_Lines::CSG_Lines(const CSG_Lines &Lines)
+{
+	m_Lines.Create(0, TSG_Array_Growth::SG_ARRAY_GROWTH_0);
+
+	Create(Lines);
+}
+
+bool CSG_Lines::Create(const CSG_Lines &Lines)
+{
+	return( Assign(Lines) );
+}
+
+CSG_Lines::CSG_Lines(sLong nLines)
+{
+	m_Lines.Create(0, TSG_Array_Growth::SG_ARRAY_GROWTH_0);
+
+	Create(nLines);
+}
+
+bool CSG_Lines::Create(sLong nLines)
+{
+	return( Set_Count(nLines) );
+}
+
+//---------------------------------------------------------
+CSG_Lines::~CSG_Lines(void)
+{
+	Destroy();
+}
+
+//---------------------------------------------------------
+bool CSG_Lines::Destroy(void)
+{
+	return( Set_Count(0) );
+}
+
+//---------------------------------------------------------
+bool CSG_Lines::Clear(void)
+{
+	return( Set_Count(0) );
+}
+
+//---------------------------------------------------------
+bool CSG_Lines::Assign(const CSG_Lines &Lines)
+{
+	if( Set_Count(Lines.Get_Count()) )
+	{
+		for(sLong i=0; i<Lines.Get_Count(); i++)
+		{
+			Get_Line(i).Assign(Lines[i]);
+		}
+
+		return( true );
+	}
+
+	return( false );
+}
+
+//---------------------------------------------------------
+CSG_Points & CSG_Lines::Add(void)
+{
+	Set_Count(Get_Count() + 1);
+
+	return( Get_Line(Get_Count() - 1) );
+}
+
+//---------------------------------------------------------
+bool CSG_Lines::Add(const CSG_Points &Line)
+{
+	Add().Assign(Line);
+
+	return( true );
+}
+
+//---------------------------------------------------------
+bool CSG_Lines::Add(const CSG_Lines &Lines)
+{
+	for(sLong i=0; i<Lines.Get_Count(); i++)
+	{
+		Add(Lines[i]);
+	}
+
+	return( true );
+}
+
+//---------------------------------------------------------
+bool CSG_Lines::Del(sLong Index)
+{
+	if( Index >= 0 && Index < m_Lines.Get_Size() )
+	{
+		delete((CSG_Points *)m_Lines[Index]);
+
+		return( m_Lines.Del(Index) );
+	}
+
+	return( false );
+}
+
+//---------------------------------------------------------
+bool CSG_Lines::Set_Count(sLong new_Count)
+{
+	if( new_Count < 0 )
+	{
+		new_Count = 0;
+	}
+
+	sLong old_Count = m_Lines.Get_Size();
+
+	if( new_Count > old_Count )
+	{
+		m_Lines.Set_Array(new_Count);
+
+		for(sLong i=old_Count; i<new_Count; i++)
+		{
+			m_Lines[i] = new CSG_Points;
+		}
+	}
+	else if( new_Count < old_Count )
+	{
+		for(sLong i=new_Count; i<old_Count; i++)
+		{
+			delete((CSG_Points *)m_Lines[i]);
+		}
+
+		m_Lines.Set_Array(new_Count);
+	}
+
+	return( true );
+}
+
+double CSG_Lines::Get_Length(void) const
+{
+	double Length = 0.;
+
+	for(sLong i=0; i<Get_Count(); i++)
+	{
+		Length += Get_Length(i);
+	}
+
+	return( Length );
+}
+
+double CSG_Lines::Get_Length(sLong Index) const
+{
+	double Length = 0.;
+
+	if( Index >= 0 && Index < Get_Count() )
+	{
+		const CSG_Points &Line = Get_Line(Index);
+
+		if( Line.Get_Count() > 1 )
+		{
+			for(sLong i=0, j=1; j<Line.Get_Count(); i++, j++)
+			{
+				Length += SG_Get_Distance(Line[i], Line[j]);
+			}
+		}
+	}
+
+	return( Length );
+}
+
+
 ///////////////////////////////////////////////////////////
 //														 //
 //														 //
@@ -368,6 +550,13 @@ CSG_Points_3D::CSG_Points_3D(void)
 	m_Points.Create(sizeof(TSG_Point_3D), 0, TSG_Array_Growth::SG_ARRAY_GROWTH_1);
 }
 
+CSG_Points_3D::CSG_Points_3D(const CSG_Points_3D &Points)
+{
+	m_Points.Create(sizeof(CSG_Points_3D), 0, TSG_Array_Growth::SG_ARRAY_GROWTH_1);
+
+	Assign(Points);
+}
+
 CSG_Points_3D::CSG_Points_3D(sLong nPoints, TSG_Array_Growth Growth)
 {
 	m_Points.Create(sizeof(TSG_Point_3D), nPoints, Growth);
@@ -419,6 +608,13 @@ CSG_Points_Int::CSG_Points_Int(void)
 	m_Points.Create(sizeof(TSG_Point_Int), 0, TSG_Array_Growth::SG_ARRAY_GROWTH_1);
 }
 
+CSG_Points_Int::CSG_Points_Int(const CSG_Points_Int &Points)
+{
+	m_Points.Create(sizeof(TSG_Point_Int), 0, TSG_Array_Growth::SG_ARRAY_GROWTH_1);
+
+	Assign(Points);
+}
+
 CSG_Points_Int::CSG_Points_Int(sLong nPoints, TSG_Array_Growth Growth)
 {
 	m_Points.Create(sizeof(TSG_Point_Int), nPoints, Growth);
@@ -632,6 +828,13 @@ void CSG_Rect::Deflate(double d, bool bPercent)
 	Deflate(d, d, bPercent);
 }
 
+//---------------------------------------------------------
+void CSG_Rect::Union(double x, double y)
+{
+	if( xMin > x ) { xMin = x; } else if( xMax < x ) { xMax = x; }
+	if( yMin > y ) { yMin = y; } else if( yMax < y ) { yMax = y; }
+}
+
 //---------------------------------------------------------
 void CSG_Rect::Union(const CSG_Point &Point)
 {
@@ -718,15 +921,20 @@ bool CSG_Rect::Contains(const CSG_Point &Point) const
 
 ///////////////////////////////////////////////////////////
 //														 //
-//														 //
-//														 //
 ///////////////////////////////////////////////////////////
 
 //---------------------------------------------------------
 CSG_Rects::CSG_Rects(void)
 {
-	m_nRects = 0;
-	m_Rects  = NULL;
+	m_nRects = 0; m_Rects = NULL;
+}
+
+//---------------------------------------------------------
+CSG_Rects::CSG_Rects(const CSG_Rects &Rects)
+{
+	m_nRects = 0; m_Rects = NULL;
+
+	Assign(Rects);
 }
 
 //---------------------------------------------------------
@@ -796,6 +1004,341 @@ bool CSG_Rects::Add(const CSG_Rect &Rect)
 }
 
 
+///////////////////////////////////////////////////////////
+//														 //
+//						CSG_Rect_Int					 //
+//														 //
+///////////////////////////////////////////////////////////
+
+//---------------------------------------------------------
+CSG_Rect_Int::CSG_Rect_Int(void)
+{
+	Assign(0, 0, 0, 0);
+}
+
+CSG_Rect_Int::CSG_Rect_Int(const CSG_Rect_Int &Rect)
+{
+	Assign(Rect.xMin, Rect.yMin, Rect.xMax, Rect.yMax);
+}
+
+CSG_Rect_Int::CSG_Rect_Int(const TSG_Rect_Int &Rect)
+{
+	Assign(Rect.xMin, Rect.yMin, Rect.xMax, Rect.yMax);
+}
+
+CSG_Rect_Int::CSG_Rect_Int(const TSG_Point_Int &A, const TSG_Point_Int &B)
+{
+	Assign(A.x, A.y, B.x, B.y);
+}
+
+CSG_Rect_Int::CSG_Rect_Int(int xMin, int yMin, int xMax, int yMax)
+{
+	Assign(xMin, yMin, xMax, yMax);
+}
+
+//---------------------------------------------------------
+CSG_Rect_Int::~CSG_Rect_Int(void)
+{}
+
+//---------------------------------------------------------
+bool CSG_Rect_Int::operator == (const CSG_Rect_Int &Rect) const
+{
+	return( is_Equal(Rect) );
+}
+
+bool CSG_Rect_Int::operator != (const CSG_Rect_Int &Rect) const
+{
+	return( !is_Equal(Rect) );
+}
+
+CSG_Rect_Int & CSG_Rect_Int::operator = (const CSG_Rect_Int &Rect)
+{
+	Assign(Rect);
+
+	return( *this );
+}
+
+void CSG_Rect_Int::operator += (const TSG_Point_Int &Point)
+{
+	Move( Point.x,  Point.y);
+}
+
+void CSG_Rect_Int::operator -= (const TSG_Point_Int &Point)
+{
+	Move(-Point.y, -Point.y);
+}
+
+//---------------------------------------------------------
+void CSG_Rect_Int::Assign(int xMin, int yMin, int xMax, int yMax)
+{
+	if( xMin < xMax )
+	{
+		this->xMin	= xMin;
+		this->xMax	= xMax;
+	}
+	else
+	{
+		this->xMin	= xMax;
+		this->xMax	= xMin;
+	}
+
+	if( yMin < yMax )
+	{
+		this->yMin	= yMin;
+		this->yMax	= yMax;
+	}
+	else
+	{
+		this->yMin	= yMax;
+		this->yMax	= yMin;
+	}
+}
+
+void CSG_Rect_Int::Assign(const TSG_Point_Int &A, const TSG_Point_Int &B)
+{
+	Assign(A.x, A.y, B.x, B.y);
+}
+
+void CSG_Rect_Int::Assign(const CSG_Rect_Int &Rect)
+{
+	Assign(Rect.xMin, Rect.yMin, Rect.xMax, Rect.yMax);
+}
+
+//---------------------------------------------------------
+void CSG_Rect_Int::Set_BottomLeft(int x, int y)
+{
+	Assign(x, y, xMax, yMax);
+}
+
+void CSG_Rect_Int::Set_BottomLeft(const TSG_Point_Int &Point)
+{
+	Set_BottomLeft(Point.x, Point.y );
+}
+
+void CSG_Rect_Int::Set_TopRight(int x, int y)
+{
+	Assign(xMin, yMin, x, y);
+}
+
+void CSG_Rect_Int::Set_TopRight(const TSG_Point_Int &Point)
+{
+	Set_TopRight(Point.x, Point.y );
+}
+
+//---------------------------------------------------------
+bool CSG_Rect_Int::is_Equal(int xMin, int yMin, int xMax, int yMax) const
+{
+	return( (this->xMin == xMin) && (this->yMin == yMin)
+		&&  (this->xMax == xMax) && (this->yMax == yMax) );
+}
+
+bool CSG_Rect_Int::is_Equal(const CSG_Rect_Int &Rect) const
+{
+	return(	is_Equal(Rect.xMin, Rect.yMin, Rect.xMax, Rect.yMax) );
+}
+
+//---------------------------------------------------------
+void CSG_Rect_Int::Move(int dx, int dy)
+{
+	xMin += dx; yMin += dy;
+	xMax += dx; yMax += dy;
+}
+
+void CSG_Rect_Int::Move(const TSG_Point_Int &Point)
+{
+	Move(Point.x, Point.y);
+}
+
+//---------------------------------------------------------
+void CSG_Rect_Int::Inflate(int dx, int dy)
+{
+	Assign(xMin - dx, yMin - dy, xMax + dx, yMax + dy);
+}
+
+void CSG_Rect_Int::Inflate(int d)
+{
+	Inflate(d, d);
+}
+
+void CSG_Rect_Int::Deflate(int dx, int dy)
+{
+	Inflate(-dx, -dy);
+}
+
+void CSG_Rect_Int::Deflate(int d)
+{
+	Deflate(d, d);
+}
+
+//---------------------------------------------------------
+void CSG_Rect_Int::Union(int x, int y)
+{
+	if( xMin > x ) { xMin = x; } else if( xMax < x ) { xMax = x; }
+	if( yMin > y ) { yMin = y; } else if( yMax < y ) { yMax = y; }
+}
+
+//---------------------------------------------------------
+void CSG_Rect_Int::Union(const TSG_Point_Int &Point)
+{
+	if( xMin > Point.x ) { xMin = Point.x; } else if( xMax < Point.x ) { xMax = Point.x; }
+	if( yMin > Point.y ) { yMin = Point.y; } else if( yMax < Point.y ) { yMax = Point.y; }
+}
+
+//---------------------------------------------------------
+void CSG_Rect_Int::Union(const CSG_Rect_Int &Rect)
+{
+	if( xMin > Rect.Get_XMin() ) { xMin = Rect.Get_XMin(); }
+	if( yMin > Rect.Get_YMin() ) { yMin = Rect.Get_YMin(); }
+	if( xMax < Rect.Get_XMax() ) { xMax = Rect.Get_XMax(); }
+	if( yMax < Rect.Get_YMax() ) { yMax = Rect.Get_YMax(); }
+}
+
+//---------------------------------------------------------
+bool CSG_Rect_Int::Intersect(const CSG_Rect_Int &Rect)
+{
+	switch( Intersects(Rect) )
+	{
+	case INTERSECTION_None: default:
+		return( false );
+
+	case INTERSECTION_Identical:
+	case INTERSECTION_Contained:
+		break;
+
+	case INTERSECTION_Contains:
+		(*this)	= Rect;
+		break;
+
+	case INTERSECTION_Overlaps:
+		if( xMin < Rect.Get_XMin() ) { xMin = Rect.Get_XMin(); }
+		if( yMin < Rect.Get_YMin() ) { yMin = Rect.Get_YMin(); }
+		if( xMax > Rect.Get_XMax() ) { xMax = Rect.Get_XMax(); }
+		if( yMax > Rect.Get_YMax() ) { yMax = Rect.Get_YMax(); }
+		break;
+	}
+
+	return( true );
+}
+
+//---------------------------------------------------------
+TSG_Intersection CSG_Rect_Int::Intersects(const CSG_Rect_Int &Rect) const
+{
+	if(	xMax < Rect.Get_XMin() || Rect.Get_XMax() < xMin
+	||	yMax < Rect.Get_YMin() || Rect.Get_YMax() < yMin )
+	{
+		return( INTERSECTION_None );
+	}
+
+	if(	is_Equal(Rect) )
+	{
+		return( INTERSECTION_Identical );
+	}
+
+	if(	Contains(Rect.Get_XMin(), Rect.Get_YMin())
+	&&	Contains(Rect.Get_XMax(), Rect.Get_YMax()) )
+	{
+		return( INTERSECTION_Contains );
+	}
+
+	if(	Rect.Contains(Get_XMin(), Get_YMin())
+	&&	Rect.Contains(Get_XMax(), Get_YMax()) )
+	{
+		return( INTERSECTION_Contained );
+	}
+
+	return( INTERSECTION_Overlaps );
+}
+
+//---------------------------------------------------------
+bool CSG_Rect_Int::Contains(double x, double y) const
+{
+	return( xMin <= x && x <= xMax && yMin <= y && y <= yMax );
+}
+
+bool CSG_Rect_Int::Contains(const TSG_Point_Int &Point) const
+{
+	return( Contains(Point.x, Point.y) );
+}
+
+
+///////////////////////////////////////////////////////////
+//														 //
+///////////////////////////////////////////////////////////
+
+//---------------------------------------------------------
+CSG_Rects_Int::CSG_Rects_Int(void)
+{
+	m_nRects = 0;
+	m_Rects  = NULL;
+}
+
+//---------------------------------------------------------
+CSG_Rects_Int::~CSG_Rects_Int(void)
+{
+	Clear();
+}
+
+//---------------------------------------------------------
+void CSG_Rects_Int::Clear(void)
+{
+	if( m_Rects )
+	{
+		for(int i=0; i<m_nRects; i++)
+		{
+			delete(m_Rects[i]);
+		}
+
+		SG_Free(m_Rects);
+	}
+
+	m_nRects = 0;
+	m_Rects  = NULL;
+}
+
+//---------------------------------------------------------
+bool CSG_Rects_Int::Assign(const CSG_Rects_Int &Rects)
+{
+	Clear();
+
+	for(int i=0; i<Rects.m_nRects; i++)
+	{
+		Add(*Rects.m_Rects[i]);
+	}
+
+	return( true );
+}
+
+//---------------------------------------------------------
+CSG_Rects_Int & CSG_Rects_Int::operator  = (const CSG_Rects_Int &Rects)
+{
+	Assign(Rects);
+
+	return( *this );
+}
+
+//---------------------------------------------------------
+bool CSG_Rects_Int::Add(void)
+{
+	return( Add(CSG_Rect_Int()) );
+}
+
+//---------------------------------------------------------
+bool CSG_Rects_Int::Add(int xMin, int yMin, int xMax, int yMax)
+{
+	return( Add(CSG_Rect_Int(xMin, yMin, xMax, yMax)) );
+}
+
+//---------------------------------------------------------
+bool CSG_Rects_Int::Add(const CSG_Rect_Int &Rect)
+{
+	m_Rects           = (CSG_Rect_Int **)SG_Realloc(m_Rects, ((uLong)m_nRects + 1) * sizeof(CSG_Rect_Int *));
+	m_Rects[m_nRects] = new CSG_Rect_Int(Rect);
+	m_nRects++;
+
+	return( true );
+}
+
+
 ///////////////////////////////////////////////////////////
 //														 //
 //														 //
@@ -822,10 +1365,12 @@ bool CSG_Distance_Weighting::Create_Parameters(CSG_Parameters &Parameters, const
 {
 	if( Add_Parameters(Parameters, Parent, bIDW_Offset) )
 	{
-		if( Parameters("DW_WEIGHTING" ) ) { Parameters("DW_WEIGHTING" )->Set_Value((int)m_Weighting  ); }
-		if( Parameters("DW_IDW_POWER" ) ) { Parameters("DW_IDW_POWER" )->Set_Value(     m_IDW_Power  ); }
-		if( Parameters("DW_IDW_OFFSET") ) { Parameters("DW_IDW_OFFSET")->Set_Value(     m_IDW_bOffset); }
-		if( Parameters("DW_BANDWIDTH" ) ) { Parameters("DW_BANDWIDTH" )->Set_Value(     m_Bandwidth  ); }
+		#define INIT_VALUE(id, val) if( Parameters(id) ) { Parameters(id)->Set_Value(val); Parameters(id)->Set_Default(val); }
+
+		INIT_VALUE("DW_WEIGHTING" ,(int)m_Weighting  );
+		INIT_VALUE("DW_IDW_POWER" ,     m_IDW_Power  );
+		INIT_VALUE("DW_IDW_OFFSET",     m_IDW_bOffset);
+		INIT_VALUE("DW_BANDWIDTH" ,     m_Bandwidth  );
 
 		return( true );
 	}
